# $Id: Request.pm 36180 2011-12-08 13:57:04Z wsl $
# $URL: https://svn.uvt.nl/its-id/trunk/sources/aselect-perl/lib/Aselect/UI/Cancel/Request.pm $

use strict;
use warnings FATAL => 'all';
use utf8;

package Aselect::UI::Cancel::Request;

use Aselect::Request -self;

bool_param cancel;

const credentials => 'canceled';
